==> pykawaii-3.6.0.tar.gz: pykawaii-3.6.0/pykawaii/http.py <==
"""
MIT License

Copyright (c) 2022 Okimii

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

import aiohttp

from .cache import Cache

__all__ = ["HTTPClient"]


class HTTPClient:

    BASE = "https://api.waifu.pics/"

    def __init__(self, cache: Cache) -> None:
        self.cache = cache()

    async def request(self, type: str, category: str, /) -> str:
        async with aiohttp.request("GET", f"{self.BASE}{type}/{category}") as payload:
            parsedpayload = (await payload.json()).get("url") or "Not found"
            self.cache.setobj(parsedpayload)
            return parsedpayload

==> pykawaii-3.9.0.tar.gz: pykawaii-3.9.0/pykawaii/http.py <==
"""
MIT License

Copyright (c) 2022 Okimii

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

import aiohttp

from .cache import Cache

__all__ = ["HTTPClient"]


class HTTPClient:

    BASE = "https://api.waifu.pics"

    def __init__(self) -> None:
        self.cache = Cache()

    async def request(self, type: str, category: str, /) -> str:
        async with aiohttp.request("GET", f"{self.BASE}/{type}/{category}") as payload:
            parsedpayload = (await payload.json()).get("url", "Not found")
            self.cache.setobj(parsedpayload)
            return parsedpayload
